#!/bin/bash
# Copyright © Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2021 All Rights Reserved
#
# Licensed under CLOUD LINUX LICENSE AGREEMENT
# http://cloudlinux.com/docs/LICENSE.TXT

# RPM post script, no arguments
# Note: Also called from Debian postinst scriptlet
# "$1" == "configure" - RPM post/posttrans
# "$1" == "abort-upgrade" - upgrade package error
# "$1" == "abort-remove" - remove package error

# $2: The version of the package being upgraded from. If empty, it indicates a fresh installation (not an upgrade).

# "alt-php-ssa POST INSTALL STARTED"

# fresh install, not upgrade
if [[  "$1" == 1 || -z "$2" ]]; then
     systemctl enable ssa-agent >/dev/null 2>&1 || :
else
    # update, not install
    if /usr/sbin/cloudlinux-ssa-manager get-ssa-status|grep -q enabled || /usr/sbin/cloudlinux-autotracing status|grep -q enabled; then
        /usr/sbin/cloudlinux-ssa-manager disable-ssa >/dev/null 2>&1 || :
        # Copy clos_ssa.so for DirectAdmin once again,
        # obligatory prior to SSA enable, to fix potential
        # PHP Startup: Unable to load dynamic library 'clos_ssa.so'
        if [ -e /usr/local/directadmin/custombuild/build ]; then
            /usr/share/clos_ssa/da_cp_ssa >/dev/null 2>&1 || :
        fi
        /usr/sbin/cloudlinux-ssa-manager enable-ssa >/dev/null 2>&1 || :
  fi
fi

# Copy clos_ssa.so for DirectAdmin, no matter install or upgrade;
# obligatory prior to SSA enable or we will face
# PHP Startup: Unable to load dynamic library 'clos_ssa.so'
if [ -e /usr/local/directadmin/custombuild/build ]; then
  /usr/share/clos_ssa/da_cp_ssa >/dev/null 2>&1 || :
fi

# delete unnecessary 'clos_ssa.ini' if they exist
/usr/share/clos_ssa/remove_extra_ssa_ini.sh >/dev/null 2>&1 || :

/bin/systemctl daemon-reload >/dev/null 2>&1 || :
/bin/systemctl try-restart ssa-agent.service >/dev/null 2>&1 || :

# "alt-php-ssa POST INSTALL FINISHED"